This dataset, alfalfa_soil, is a data frame containing alfalfa soil requirement information for land evaluation. It includes codes for soil parameters together with values across suitability classes and weights.
Usage
data(alfalfa_soil)Format
A data frame with 12 observations and 8 variables:
- code
Character vector indicating the soil parameter code
- s3_a
Character vector indicating the s3_a value
- s2_a
Character vector indicating the s2_a value
- s1_a
Character vector indicating the s1_a value
- s1_b
Character vector indicating the s1_b value
- s2_b
Character vector indicating the s2_b value
- s3_b
Character vector indicating the s3_b value
- wts
Character vector indicating the weight