Arabica Coffee Water Requirement for Land Evaluation
Source:R/data-documentation.R
arabica_water.RdThis dataset, arabica_water, is a data frame containing arabica coffee water requirement information for land evaluation. It includes codes for water-related parameters together with values across suitability classes and weights.
Usage
data(arabica_water)Format
A data frame with 4 observations and 8 variables:
- code
Character vector indicating the water-related parameter code
- s3_a
Character vector indicating the s3_a value
- s2_a
Character vector indicating the s2_a value
- s1_a
Character vector indicating the s1_a value
- s1_b
Character vector indicating the s1_b value
- s2_b
Character vector indicating the s2_b value
- s3_b
Character vector indicating the s3_b value
- wts
Character vector indicating the weight