This dataset, apple_canker, is a data frame containing apple canker infestation data across apple cultivars and inoculum levels. It includes information on inoculum level, cultivar, block, number infested, and total number of shoots.
Usage
data(apple_canker)Format
A data frame with 36 observations and 5 variables:
- inoculum
Integer vector indicating the inoculum level
- gen
Factor w/ 3 levels indicating the cultivar
- block
Factor w/ 4 levels indicating the block
- y
Integer vector indicating the number of infested shoots
- n
Integer vector indicating the total number of shoots