This dataset, black_duck_survival, is a data frame containing survival data on black ducks (Anas rubripes) followed by the US Fish and Wildlife Service. It includes information on duck identifier, time, status, age, weight, and length.
Usage
data(black_duck_survival)Format
A data frame with 50 observations and 6 variables:
- duck
Integer vector indicating the duck identifier
- time
Integer vector indicating the time
- status
Integer vector indicating the status
- age
Integer vector indicating the age
- weight
Integer vector indicating the weight
- length
Integer vector indicating the length