This dataset, blackgrass_herbicide, is a data frame containing data from a factorial experiment conducted to evaluate the efficacy of three herbicides across nine different populations of black-grass. It includes information on plot identifier, replicate, pot, population, type, herbicide, and fresh weight.
Usage
data(blackgrass_herbicide)Format
A data frame with 135 observations and 7 variables:
- ID
Factor w/ 135 levels indicating the plot identifier
- Rep
Factor w/ 5 levels indicating the replicate
- DPot
Factor w/ 27 levels indicating the pot
- Population
Factor w/ 9 levels indicating the black-grass population
- Type
Factor w/ 2 levels indicating the type
- Herbicide
Factor w/ 3 levels indicating the herbicide
- Fwt
Numeric vector indicating the fresh weight