This dataset, broiler_growth, is a data frame containing daily weight, feed, and egg measurements for a broiler chicken. It includes information on body weight, target body weight, average daily feed intake, average daily gain, egg weight, and age.
Usage
data(broiler_growth)Format
A data frame with 59 observations and 6 variables:
- bw
Integer vector indicating the body weight
- targetbw
Integer vector indicating the target body weight
- adfi
Numeric vector indicating the average daily feed intake
- adg
Numeric vector indicating the average daily gain
- eggwt
Numeric vector indicating the egg weight
- age
Integer vector indicating the age