This dataset, carrot_fly_infestation, is a data frame containing carrot fly infestation data across carrot genotypes and treatments. It includes information on treatment, genotype, block, total number of plants, and number of infested plants.
Usage
data(carrot_fly_infestation)Format
A data frame with 96 observations and 5 variables:
- trt
Factor w/ 2 levels indicating the treatment
- gen
Factor w/ 16 levels indicating the genotype
- block
Factor w/ 3 levels indicating the block
- n
Integer vector indicating the total number of plants
- y
Integer vector indicating the number of infested plants