This dataset, carrot_insecticide, is a data frame containing carrot fly damage data for different insecticide treatments and depths. It includes information on treatment, insecticide, depth, replicate, number of damaged carrots, and total number of carrots.
Usage
data(carrot_insecticide)Format
A data frame with 36 observations and 6 variables:
- treatment
Factor w/ 11 levels indicating the treatment
- insecticide
Factor w/ 3 levels indicating the insecticide
- depth
Numeric vector indicating the depth
- rep
Factor w/ 3 levels indicating the replicate
- damaged
Integer vector indicating the number of damaged carrots
- total
Integer vector indicating the total number of carrots