This dataset, cattle_butterfat, is a data frame containing the average butterfat content for dairy cattle. It includes information on butterfat content, breed, and age.
Usage
data(cattle_butterfat)This dataset, cattle_butterfat, is a data frame containing the average butterfat content for dairy cattle. It includes information on butterfat content, breed, and age.
data(cattle_butterfat)