This dataset, cork_tree_direction, is a data frame containing weight measurements of cork samples taken from four sides of trees. It includes information on tree identifier, direction, and weight.
Usage
data(cork_tree_direction)This dataset, cork_tree_direction, is a data frame containing weight measurements of cork samples taken from four sides of trees. It includes information on tree identifier, direction, and weight.
data(cork_tree_direction)