This dataset, cowpea_maize_yield, is a data frame containing maize and cowpea yield data under different nitrogen levels from an intercropping experiment. It includes information on block, nitrogen level, cowpea variety, maize variety, cowpea yield, and maize yield.
Usage
data(cowpea_maize_yield)Format
A data frame with 72 observations and 6 variables:
- block
Factor w/ 3 levels indicating the block
- nitro
Factor w/ 4 levels indicating the nitrogen level
- cowpea
Factor w/ 2 levels indicating the cowpea variety
- maize
Factor w/ 3 levels indicating the maize variety
- cyield
Integer vector indicating the cowpea yield
- myield
Integer vector indicating the maize yield