This dataset, eelworm_fumigation, is a data frame containing counts of eelworms before and after fumigant treatments. It includes information on block, row, column, fumigant, dose, initial and final eelworm counts, grain, straw, and weeds.
Usage
data(eelworm_fumigation)Format
A data frame with 48 observations and 10 variables:
- block
Factor w/ 4 levels indicating the block
- row
Integer vector indicating the row
- col
Integer vector indicating the column
- fumigant
Factor w/ 5 levels indicating the fumigant
- dose
Integer vector indicating the dose
- initial
Integer vector indicating the initial eelworm count
- final
Integer vector indicating the final eelworm count
- grain
Numeric vector indicating the grain measurement
- straw
Numeric vector indicating the straw measurement
- weeds
Numeric vector indicating the weeds measurement