This dataset, egg_weight_daily, is a data frame containing a sample of egg weights collected on 24 consecutive days. It includes information on day and weight.
Usage
data(egg_weight_daily)This dataset, egg_weight_daily, is a data frame containing a sample of egg weights collected on 24 consecutive days. It includes information on day and weight.
data(egg_weight_daily)