This dataset, eucalyptus_progenies, is a data frame containing height measurements of 7-year-old Eucalyptus grandis trees. It includes observations across three trials and six progenies arranged in randomized blocks.
Usage
data(eucalyptus_progenies)This dataset, eucalyptus_progenies, is a data frame containing height measurements of 7-year-old Eucalyptus grandis trees. It includes observations across three trials and six progenies arranged in randomized blocks.
data(eucalyptus_progenies)