This dataset, fish_feeding, is a data frame containing the food consumption for various fish species. It includes information on species, maximum weight, temperature, aspect ratio, food type, and food consumption.
Usage
data(fish_feeding)Format
A data frame with 33 observations and 6 variables:
- Species
Factor w/ 33 levels indicating the species
- MaxWt
Integer vector indicating the maximum weight
- Temp
Integer vector indicating the temperature
- AR
Numeric vector indicating the aspect ratio
- Food
Factor w/ 2 levels indicating the food type
- FoodCon
Numeric vector indicating the food consumption