This dataset, hawaii_plant_size, is a data frame containing maximum plant size measurements for species in the Hawaiian archipelago. It includes information on species, family, native status, sample size, 95th percentile diameter, and maximum diameter of the three largest individuals.
Usage
data(hawaii_plant_size)Format
A data frame with 58 observations and 6 variables:
- species
Character vector indicating the species
- family
Integer vector indicating the family code
- native.status
Factor w/ 2 levels indicating the native status
- n
Integer vector indicating the sample size
- d95
Numeric vector indicating the 95th percentile diameter
- dmax3
Numeric vector indicating the maximum diameter of the three largest individuals