This dataset, hawaii_tree_growth, is a data frame containing diameter growth increments of a tropical tree species in Hawaii. It includes information on tree code, diameter at breast height, total height, crown area, competition index, and current annual increment for 1986, 1987, and 1988.
Usage
data(hawaii_tree_growth)Format
A data frame with 63 observations and 8 variables:
- tree.code
Factor w/ 63 levels indicating the tree code
- dbh
Numeric vector indicating the diameter at breast height
- toth
Numeric vector indicating the total height
- crown.area
Numeric vector indicating the crown area
- comp.ind
Numeric vector indicating the competition index
- cai.1986
Numeric vector indicating the current annual increment for 1986
- cai.1987
Numeric vector indicating the current annual increment for 1987
- cai.1988
Numeric vector indicating the current annual increment for 1988