This dataset, idn_rice_farms, is a data frame containing observations on rice production farms in Indonesia. It includes information on farm size, status, rice varieties, program participation, input use, labor, wages, output, price, and region.
Usage
data(idn_rice_farms)Format
A data frame with 1026 observations and 20 variables:
- id
Integer vector indicating the farm identifier
- size
Numeric vector indicating the farm size
- status
Factor w/ 3 levels indicating the status
- varieties
Factor w/ 3 levels indicating the rice varieties
- bimas
Factor w/ 3 levels indicating the bimas program participation
- seed
Integer vector indicating the seed quantity
- urea
Integer vector indicating the urea quantity
- phosphate
Integer vector indicating the phosphate quantity
- pesticide
Integer vector indicating the pesticide quantity
- pseed
Numeric vector indicating the price of seed
- purea
Numeric vector indicating the price of urea
- pphosph
Numeric vector indicating the price of phosphate
- hiredlabor
Integer vector indicating the hired labor
- famlabor
Integer vector indicating the family labor
- totlabor
Integer vector indicating the total labor
- wage
Numeric vector indicating the wage
- goutput
Integer vector indicating the gross output
- noutput
Integer vector indicating the net output
- price
Numeric vector indicating the price
- region
Factor w/ 6 levels indicating the region