This dataset, kiwi_crop_design, is a data frame containing the experimental design of a kiwifruit cover crop study. It includes information on sample identifier and treatment.
Usage
data(kiwi_crop_design)This dataset, kiwi_crop_design, is a data frame containing the experimental design of a kiwifruit cover crop study. It includes information on sample identifier and treatment.
data(kiwi_crop_design)