This dataset, ladybird_fungus, is a data frame containing data from an experiment conducted to study the transmission of fungus from ladybirds to aphids on two host plant types (beans or birdsfoot trefoil). It includes information on plot identifier, run, plant, host, ladybird presence, number of cadavers, number of live aphids, and number of infected aphids.
Usage
data(ladybird_fungus)Format
A data frame with 72 observations and 8 variables:
- ID
Factor w/ 72 levels indicating the plot identifier
- Run
Factor w/ 2 levels indicating the run
- DPlant
Factor w/ 36 levels indicating the plant
- Host
Factor w/ 2 levels indicating the host plant type
- Ladybird
Factor w/ 2 levels indicating the ladybird presence
- Cadaver
Integer vector indicating the number of cadavers
- Live
Integer vector indicating the number of live aphids
- Infected
Integer vector indicating the number of infected aphids