This dataset, nitrofen_toxicity, is a data frame containing data from an experiment to measure the reproductive toxicity of nitrofen on a species of zooplankton (Ceriodaphnia dubia). Fifty animals were randomized into batches of ten and each batch was put in a solution with a measured concentration of nitrofen. It includes information on nitrofen concentration and brood sizes across three broods along with the total.
Usage
data(nitrofen_toxicity)Format
A data frame with 50 observations and 5 variables:
- conc
Numeric vector indicating the nitrofen concentration
- brood1
Numeric vector indicating the number of offspring in brood 1
- brood2
Numeric vector indicating the number of offspring in brood 2
- brood3
Numeric vector indicating the number of offspring in brood 3
- total
Numeric vector indicating the total number of offspring