This dataset, orange_rootstocks, is a data frame containing observations on orange plants grown under different rootstocks. It includes information on rootstock treatment, block, and the corresponding response variable.
Usage
data(orange_rootstocks)This dataset, orange_rootstocks, is a data frame containing observations on orange plants grown under different rootstocks. It includes information on rootstock treatment, block, and the corresponding response variable.
data(orange_rootstocks)