This dataset, pig_weight_gain, is a data frame containing weight gain data in pigs for different treatments. It includes information on pen, treatment, pig identifier, sex, initial weight, final weight, feed consumption, adjusted initial weight, average daily gain, and feed conversion ratio.
Usage
data(pig_weight_gain)Format
A data frame with 30 observations and 10 variables:
- pen
Factor w/ 5 levels indicating the pen
- treatment
Factor w/ 3 levels indicating the treatment
- pig
Integer vector indicating the pig identifier
- sex
Factor w/ 2 levels indicating the sex
- weight1
Numeric vector indicating the initial weight
- weight2
Numeric vector indicating the final weight
- feed
Numeric vector indicating the feed consumption
- w0
Integer vector indicating the adjusted initial weight
- g
Numeric vector indicating the average daily gain
- h
Numeric vector indicating the feed conversion ratio