This dataset, plant_growth_regulator, is a data frame containing plant height measurements from a glasshouse experiment conducted to examine how different doses of a growth regulator affect plant height under controlled conditions. It includes information on pot, row, column, growth regulator dose, and plant height.
Usage
data(plant_growth_regulator)Format
A data frame with 24 observations and 5 variables:
- Pot
Factor w/ 24 levels indicating the pot
- Row
Factor w/ 4 levels indicating the row
- Column
Factor w/ 6 levels indicating the column
- Dose
Factor w/ 6 levels indicating the growth regulator dose
- Height
Numeric vector indicating the plant height