This dataset, potato_scab_sulfur, is a data frame containing observations on potato scab infection under different sulfur treatments. It includes information on infection score, treatment, row, and column.
Usage
data(potato_scab_sulfur)This dataset, potato_scab_sulfur, is a data frame containing observations on potato scab infection under different sulfur treatments. It includes information on infection score, treatment, row, and column.
data(potato_scab_sulfur)