This dataset, red_wine_quality, is a data frame containing physicochemical characteristics and quality ratings of red wine samples from north Portugal. It includes information on acidity, sugar, chlorides, sulfur dioxide, density, pH, sulphates, alcohol, and quality.
Usage
data(red_wine_quality)Format
A data frame with 1599 observations and 12 variables:
- fixed_acidity
Numeric vector indicating the fixed acidity
- volatile_acidity
Numeric vector indicating the volatile acidity
- citric_acid
Numeric vector indicating the citric acid content
- residual_sugar
Numeric vector indicating the residual sugar
- chlorides
Numeric vector indicating the chlorides content
- free_sulfur_dioxide
Numeric vector indicating the free sulfur dioxide
- total_sulfur_dioxide
Numeric vector indicating the total sulfur dioxide
- density
Numeric vector indicating the density
- pH
Numeric vector indicating the pH
- sulphates
Numeric vector indicating the sulphates content
- alcohol
Numeric vector indicating the alcohol content
- quality
Integer vector indicating the quality rating