This dataset, rice_wheat_production, is a data frame containing observations on rice and wheat production over multiple years. It includes information on food type, year, area, production, yield, and irrigation.
Usage
data(rice_wheat_production)This dataset, rice_wheat_production, is a data frame containing observations on rice and wheat production over multiple years. It includes information on food type, year, area, production, yield, and irrigation.
data(rice_wheat_production)