This dataset, seed_germination, is a data frame containing seed germination data under different temperatures and concentrations. It includes information on temperature, replicate, concentration, number germinated, and total number of seeds.
Usage
data(seed_germination)Format
A data frame with 64 observations and 5 variables:
- temp
Factor w/ 4 levels indicating the temperature
- rep
Factor w/ 4 levels indicating the replicate
- conc
Numeric vector indicating the concentration
- germ
Integer vector indicating the number germinated
- seeds
Integer vector indicating the total number of seeds