This dataset, soil_munsell_minerals, is a data frame containing Munsell color information for common soil minerals. It includes information on mineral name, Munsell color notation, hue, value, and chroma.
Usage
data(soil_munsell_minerals)Format
A data frame with 20 observations and 5 variables:
- mineral
Character vector indicating the mineral name
- color
Character vector indicating the Munsell color notation
- hue
Character vector indicating the Munsell hue
- value
Integer vector indicating the Munsell value
- chroma
Integer vector indicating the Munsell chroma