Ordered Disease Ratings of Strawberry Crosses
Source:R/data-documentation.R
strawberry_cross_disease.RdThis dataset, strawberry_cross_disease, is a data frame containing disease ratings for strawberry crosses across parental combinations. It includes information on male parent, female parent, block, disease category, and count.
Usage
data(strawberry_cross_disease)Format
A data frame with 144 observations and 5 variables:
- male
Factor w/ 3 levels indicating the male parent
- female
Factor w/ 4 levels indicating the female parent
- block
Factor w/ 4 levels indicating the block
- category
Factor w/ 3 levels indicating the disease category
- count
Integer vector indicating the count