This dataset, strawberry_yield, is a data frame containing strawberry yield data from a randomized complete block experiment. It includes information on row, column, block, genotype, and yield.
Usage
data(strawberry_yield)This dataset, strawberry_yield, is a data frame containing strawberry yield data from a randomized complete block experiment. It includes information on row, column, block, genotype, and yield.
data(strawberry_yield)