This dataset, us_state_soils, is a data frame containing the official state soil for each US state and territory. It includes information on the state name, its abbreviation, and the corresponding soil series.
Usage
data(us_state_soils)This dataset, us_state_soils, is a data frame containing the official state soil for each US state and territory. It includes information on the state name, its abbreviation, and the corresponding soil series.
data(us_state_soils)