This dataset, wheat_bunt, is a data frame containing fungus infection data for different wheat varieties. It includes information on bunt race, percentage infection, replicate, and genotype.
Usage
data(wheat_bunt)This dataset, wheat_bunt, is a data frame containing fungus infection data for different wheat varieties. It includes information on bunt race, percentage infection, replicate, and genotype.
data(wheat_bunt)