This dataset, wheat_splitsplit, is a data frame containing wheat yield data from a split-split-plot experiment. It includes information on row, column, yield, inoculation, treatment, genotype, moisture condition, seed treatment, and block.
Usage
data(wheat_splitsplit)Format
A data frame with 160 observations and 9 variables:
- row
Integer vector indicating the row
- col
Integer vector indicating the column
- yield
Integer vector indicating the yield
- inoc
Factor w/ 2 levels indicating the inoculation
- trt
Integer vector indicating the treatment
- gen
Factor w/ 2 levels indicating the genotype
- dry
Factor w/ 2 levels indicating the moisture condition
- dust
Factor w/ 5 levels indicating the seed treatment
- block
Factor w/ 4 levels indicating the block