Effect of Type and Size of Cutting on Willow Yield
Source:R/data-documentation.R
willow_cutting_yield.RdThis dataset, willow_cutting_yield, is a data frame containing observations on the effect of cutting type and size on willow yield. It includes information on plot identifier, block, plot, cutting type, cutting size, and yield.
Usage
data(willow_cutting_yield)Format
A data frame with 25 observations and 6 variables:
- ID
Factor w/ 25 levels indicating the plot identifier
- Block
Factor w/ 5 levels indicating the block
- Plot
Factor w/ 5 levels indicating the plot
- Type
Factor w/ 5 levels indicating the cutting type
- Size
Factor w/ 3 levels indicating the cutting size
- Yield
Numeric vector indicating the yield